@@ -1,6 +1,6 @@
 __version_info__ = {
-    'major': 0,
-    'minor': 9,
+    'major': 2,
+    'minor': 0,
     'micro': 0,
     'releaselevel': 'final',
     'serial': 0
@@ -13,7 +13,14 @@ def get_version(short=False):
     if __version_info__['micro']:
         vers.append(".%(micro)i" % __version_info__)
     if __version_info__['releaselevel'] != 'final' and not short:
-        vers.append('%s%i' % (__version_info__['releaselevel'][0], __version_info__['serial']))
+        vers.append(
+            '%s%i' % (
+                __version_info__['releaselevel'][0],
+                __version_info__['serial'])
+        )
     return ''.join(vers)
 
+
 __version__ = get_version()
+
+default_app_config = 'explorer.apps.ExplorerAppConfig'
