@@ -1,11 +1,21 @@
-from explorer.utils import passes_blacklist, swap_params, extract_params, shared_dict_update, get_connection, get_s3_connection
-from django.db import models, DatabaseError
-from time import time
-from django.core.urlresolvers import reverse
-from django.conf import settings
-from . import app_settings
 import logging
-import six
+from time import time
+
+from django.conf import settings
+from django.db import models, DatabaseError, transaction
+from django.urls import reverse
+from django.utils.translation import ugettext_lazy as _
+
+from explorer import app_settings
+from explorer.utils import (
+    passes_blacklist,
+    swap_params,
+    extract_params,
+    shared_dict_update,
+    get_s3_bucket,
+    get_params_for_url,
+    get_valid_connection
+)
 
 MSG_FAILED_BLACKLIST = "Query failed the SQL blacklist: %s"
 
@@ -16,29 +26,50 @@ logger = logging.getLogger(__name__)
 class Query(models.Model):
     title = models.CharField(max_length=255)
     sql = models.TextField()
-    description = models.TextField(null=True, blank=True)
-    created_by_user = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, blank=True)
+    description = models.TextField(default='', blank=True)
+    created_by_user = models.ForeignKey(
+        settings.AUTH_USER_MODEL,
+        null=True,
+        blank=True,
+        on_delete=models.CASCADE
+    )
     created_at = models.DateTimeField(auto_now_add=True)
     last_run_date = models.DateTimeField(auto_now=True)
-    snapshot = models.BooleanField(default=False, help_text="Include in snapshot task (if enabled)")
+    snapshot = models.BooleanField(
+        default=False,
+        help_text=_("Include in snapshot task (if enabled)")
+    )
+    connection = models.CharField(
+        blank=True,
+        max_length=128,
+        default='',
+        help_text=_(
+            "Name of DB connection (as specified in settings) to use for "
+            "this query."
+            "Will use EXPLORER_DEFAULT_CONNECTION if left blank"
+        )
+    )
 
     def __init__(self, *args, **kwargs):
         self.params = kwargs.get('params')
         kwargs.pop('params', None)
-        super(Query, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     class Meta:
         ordering = ['title']
-        verbose_name_plural = 'Queries'
+        verbose_name = _('Query')
+        verbose_name_plural = _('Queries')
 
-    def __unicode__(self):
-        return six.text_type(self.title)
+    def __str__(self):
+        return str(self.title)
 
     def get_run_count(self):
         return self.querylog_set.count()
 
     def avg_duration(self):
-        return self.querylog_set.aggregate(models.Avg('duration'))['duration__avg']
+        return self.querylog_set.aggregate(
+            models.Avg('duration')
+        )['duration__avg']
 
     def passes_blacklist(self):
         return passes_blacklist(self.final_sql())
@@ -47,7 +78,9 @@ class Query(models.Model):
         return swap_params(self.sql, self.available_params())
 
     def execute_query_only(self):
-        return QueryResult(self.final_sql())
+        return QueryResult(
+            self.final_sql(), get_valid_connection(self.connection)
+        )
 
     def execute_with_logging(self, executing_user):
         ql = self.log(executing_user)
@@ -63,12 +96,12 @@ class Query(models.Model):
 
     def available_params(self):
         """
-            Merge parameter values into a dictionary of available parameters
+        Merge parameter values into a dictionary of available parameters
 
-        :param param_values: A dictionary of Query param values.
-        :return: A merged dictionary of parameter names and values. Values of non-existent parameters are removed.
+        :return: A merged dictionary of parameter names and values.
+                 Values of non-existent parameters are removed.
+        :rtype: dict
         """
-
         p = extract_params(self.sql)
         if self.params:
             shared_dict_update(p, self.params)
@@ -77,32 +110,68 @@ class Query(models.Model):
     def get_absolute_url(self):
         return reverse("query_detail", kwargs={'query_id': self.id})
 
+    @property
+    def params_for_url(self):
+        return get_params_for_url(self)
+
     def log(self, user=None):
-        if user and user.is_anonymous():
-            user = None
-        ql = QueryLog(sql=self.final_sql(), query_id=self.id, run_by_user=user)
+        if user:
+            if user.is_anonymous:
+                user = None
+        ql = QueryLog(
+            sql=self.final_sql(),
+            query_id=self.id,
+            run_by_user=user,
+            connection=self.connection
+        )
         ql.save()
         return ql
 
     @property
     def shared(self):
-        return self.id in set(sum(app_settings.EXPLORER_GET_USER_QUERY_VIEWS().values(), []))
+        return self.id in set(
+            sum(app_settings.EXPLORER_GET_USER_QUERY_VIEWS().values(), [])
+        )
 
     @property
     def snapshots(self):
         if app_settings.ENABLE_TASKS:
-            conn = get_s3_connection()
-            res = conn.list('query-%s.snap-' % self.id)
-            return sorted(res, key=lambda s: s['last_modified'])
+            b = get_s3_bucket()
+            keys = b.list(prefix=f'query-{self.id}/snap-')
+            keys_s = sorted(keys, key=lambda k: k.last_modified)
+            return [
+                SnapShot(
+                    k.generate_url(expires_in=0, query_auth=False),
+                    k.last_modified
+                ) for k in keys_s
+            ]
+
+
+class SnapShot:
+
+    def __init__(self, url, last_modified):
+        self.url = url
+        self.last_modified = last_modified
 
 
 class QueryLog(models.Model):
 
-    sql = models.TextField(null=True, blank=True)
-    query = models.ForeignKey(Query, null=True, blank=True, on_delete=models.SET_NULL)
-    run_by_user = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, blank=True)
+    sql = models.TextField(default='', blank=True)
+    query = models.ForeignKey(
+        Query,
+        null=True,
+        blank=True,
+        on_delete=models.SET_NULL
+    )
+    run_by_user = models.ForeignKey(
+        settings.AUTH_USER_MODEL,
+        null=True,
+        blank=True,
+        on_delete=models.CASCADE
+    )
     run_at = models.DateTimeField(auto_now_add=True)
     duration = models.FloatField(blank=True, null=True)  # milliseconds
+    connection = models.CharField(blank=True, max_length=128, default='')
 
     @property
     def is_playground(self):
@@ -112,11 +181,12 @@ class QueryLog(models.Model):
         ordering = ['-run_at']
 
 
-class QueryResult(object):
+class QueryResult:
 
-    def __init__(self, sql):
+    def __init__(self, sql, connection):
 
         self.sql = sql
+        self.connection = connection
 
         cursor, duration = self.execute_query()
 
@@ -137,16 +207,19 @@ class QueryResult(object):
     def headers(self):
         return self._headers or []
 
+    @property
+    def header_strings(self):
+        return [str(h) for h in self.headers]
+
     def _get_headers(self):
         return [ColumnHeader(d[0]) for d in self._description] if self._description else [ColumnHeader('--')]
 
     def _get_numerics(self):
-        conn = get_connection()
-        if hasattr(conn.Database, "NUMBER"):
-            return [ix for ix, c in enumerate(self._description) if hasattr(c, 'type_code') and c.type_code in conn.Database.NUMBER.values]
+        if hasattr(self.connection.Database, "NUMBER"):
+            return [ix for ix, c in enumerate(self._description) if hasattr(c, 'type_code') and c.type_code in self.connection.Database.NUMBER.values]
         elif self.data:
             d = self.data[0]
-            return [ix for ix, _ in enumerate(self._description) if not isinstance(d[ix], six.string_types) and six.text_type(d[ix]).isnumeric()]
+            return [ix for ix, _ in enumerate(self._description) if not isinstance(d[ix], str) and str(d[ix]).isnumeric()]
         return []
 
     def _get_transforms(self):
@@ -176,12 +249,12 @@ class QueryResult(object):
                     r[ix] = t.format(str(r[ix]))
 
     def execute_query(self):
-        conn = get_connection()
-        cursor = conn.cursor()
+        cursor = self.connection.cursor()
         start_time = time()
 
         try:
-            cursor.execute(self.sql)
+            with transaction.atomic(self.connection.alias):
+                cursor.execute(self.sql)
         except DatabaseError as e:
             cursor.close()
             raise e
@@ -189,7 +262,7 @@ class QueryResult(object):
         return cursor, ((time() - start_time) * 1000)
 
 
-class ColumnHeader(object):
+class ColumnHeader:
 
     def __init__(self, title):
         self.title = title.strip()
@@ -198,14 +271,11 @@ class ColumnHeader(object):
     def add_summary(self, column):
         self.summary = ColumnSummary(self, column)
 
-    def __unicode__(self):
-        return self.title
-
     def __str__(self):
         return self.title
 
 
-class ColumnStat(object):
+class ColumnStat:
 
     def __init__(self, label, statfn, precision=2, handles_null=False):
         self.label = label
@@ -214,16 +284,15 @@ class ColumnStat(object):
         self.handles_null = handles_null
 
     def __call__(self, coldata):
-        self.value = round(float(self.statfn(coldata)), self.precision) if coldata else 0
+        self.value = round(
+            float(self.statfn(coldata)), self.precision
+        ) if coldata else 0
 
-    def __unicode__(self):
+    def __str__(self):
         return self.label
 
-    def foo(self):
-        return "foobar"
 
-
-class ColumnSummary(object):
+class ColumnSummary:
 
     def __init__(self, header, col):
         self._header = header
@@ -241,8 +310,7 @@ class ColumnSummary(object):
 
     @property
     def stats(self):
-        # dict comprehensions are not supported in Python 2.6, so do this instead
-        return dict((c.label, c.value) for c in self._stats)
+        return {c.label: c.value for c in self._stats}
 
     def __str__(self):
         return str(self._header)
