@@ -1,25 +1,17 @@
-from django.test import TestCase
-from explorer.actions import generate_report_action
-from explorer.tests.factories import SimpleQueryFactory
-from explorer.utils import csv_report
-import StringIO
+# -*- coding: utf-8 -*-
+import io
 from zipfile import ZipFile
 
+from django.test import TestCase
 
-class testSqlQueryActions(TestCase):
+from explorer.actions import generate_report_action
+from explorer.tests.factories import SimpleQueryFactory
 
-    def test_simple_query_runs(self):
 
-        expected_csv = 'two\r\n2\r\n'
-
-        r = SimpleQueryFactory()
-        result = csv_report(r)
-
-        self.assertIsNotNone(result, "Query '%s' returned None." % r.title)
-        self.assertEqual(result.lower(), expected_csv)
+class TestSqlQueryActions(TestCase):
 
     def test_single_query_is_csv_file(self):
-        expected_csv = 'two\r\n2\r\n'
+        expected_csv = b'two\r\n2\r\n'
 
         r = SimpleQueryFactory()
         fn = generate_report_action()
@@ -33,15 +25,17 @@ class testSqlQueryActions(TestCase):
         q = SimpleQueryFactory()
         q2 = SimpleQueryFactory()
         fn = generate_report_action()
-        res = fn(None, None, [q, q2])
-        z = ZipFile(StringIO.StringIO(res.content))
+
+        res = fn(None, None, [q,q2])
+        z = ZipFile(io.BytesIO(res.content))
         got_csv = z.read(z.namelist()[0])
 
         self.assertEqual(len(z.namelist()), 2)
-        self.assertEqual(z.namelist()[0], '%s.csv' % q.title)
-        self.assertEqual(got_csv.lower(), expected_csv)
+        self.assertEqual(z.namelist()[0], f'{q.title}.csv')
+        self.assertEqual(got_csv.lower().decode('utf-8'), expected_csv)
 
-    # if commas are not removed from the filename, then Chrome throws "duplicate headers received from server"
+    # if commas are not removed from the filename, then Chrome throws
+    # "duplicate headers received from server"
     def test_packaging_removes_commas_from_file_name(self):
 
         expected = 'attachment; filename=query for x y.csv'
