@@ -1,12 +1,16 @@
-#encoding=utf8
+# -*- coding: utf-8 -*-
+from unittest.mock import Mock
 
 from django.test import TestCase
+
+from explorer import app_settings
 from explorer.actions import generate_report_action
 from explorer.tests.factories import SimpleQueryFactory
-from explorer import app_settings
-from explorer.utils import passes_blacklist, schema_info, param, swap_params, extract_params,\
-    shared_dict_update, EXPLORER_PARAM_TOKEN, write_csv, get_params_from_request
-from mock import Mock
+from explorer.utils import (
+    passes_blacklist, param, swap_params, extract_params,
+    shared_dict_update, EXPLORER_PARAM_TOKEN, get_params_from_request,
+    get_params_for_url
+)
 
 
 class TestSqlBlacklist(TestCase):
@@ -33,7 +37,8 @@ class TestSqlBlacklist(TestCase):
         self.assertEqual(result.content.decode('utf-8'), '0')
 
     def test_queries_deleting_stuff_are_not_ok(self):
-        sql = "'distraction'; deLeTe from table; SELECT 1+1 AS TWO; drop view foo;"
+        sql = "'distraction'; deLeTe from table; " \
+              "SELECT 1+1 AS TWO; drop view foo;"
         passes, words = passes_blacklist(sql)
         self.assertFalse(passes)
         self.assertTrue(len(words), 2)
@@ -50,21 +55,6 @@ class TestSqlBlacklist(TestCase):
         self.assertTrue(passes_blacklist(sql)[0])
 
 
-class TestSchemaInfo(TestCase):
-
-    def test_schema_info_returns_valid_data(self):
-        res = schema_info()
-        tables = [a[1] for a in res]
-        self.assertIn('explorer_query', tables)
-
-    def test_app_exclusion_list(self):
-        app_settings.EXPLORER_SCHEMA_EXCLUDE_APPS = ('explorer',)
-        res = schema_info()
-        app_settings.EXPLORER_SCHEMA_EXCLUDE_APPS = ('',)
-        tables = [a[1] for a in res]
-        self.assertNotIn('explorer_query', tables)
-
-
 class TestParams(TestCase):
 
     def test_swappable_params_are_built_correctly(self):
@@ -72,8 +62,8 @@ class TestParams(TestCase):
         self.assertEqual(expected, param('foo'))
 
     def test_params_get_swapped(self):
-        sql = 'please swap $$this$$ and $$that$$'
-        expected = 'please swap here and there'
+        sql = 'please Swap $$this$$ and $$THat$$'
+        expected = 'please Swap here and there'
         params = {'this': 'here', 'that': 'there'}
         got = swap_params(sql, params)
         self.assertEqual(got, expected)
@@ -97,6 +87,7 @@ class TestParams(TestCase):
     def test_extracting_params(self):
         tests = [
             ('please swap $$this0$$',                {'this0': ''}),
+            ('please swap $$THis0$$',                {'this0': ''}),
             ('please swap $$this6$$ $$this6:that$$', {'this6': 'that'}),
             ('please swap $$this_7:foo, bar$$',      {'this_7': 'foo, bar'}),
             ('please swap $$this8:$$',               {}),
@@ -121,11 +112,28 @@ class TestParams(TestCase):
         self.assertEqual(res['foo'], 'bar')
         self.assertEqual(res['qux'], 'mux')
 
+    def test_get_params_for_request(self):
+        q = SimpleQueryFactory(params={'a': 1, 'b': 2})
+        # For some reason the order of the params is non-deterministic,
+        # causing the following to periodically fail:
+        #     self.assertEqual(get_params_for_url(q), 'a:1|b:2')
+        # So instead we go for the following, convoluted, asserts:
+        res = get_params_for_url(q)
+        res = res.split('|')
+        expected = ['a:1', 'b:2']
+        for e in expected:
+            self.assertIn(e, res)
 
-class TestCsv(TestCase):
+    def test_get_params_for_request_empty(self):
+        q = SimpleQueryFactory()
+        self.assertEqual(get_params_for_url(q), None)
 
-    def test_writing_unicode(self):
-        headers = ['a', None]
-        data = [[1, None], [u"Jenét", '1']]
-        res = write_csv(headers, data).getvalue()
-        self.assertEqual(res, 'a,\r\n1,\r\nJenét,1\r\n')
\ No newline at end of file
+
+class TestConnections(TestCase):
+
+    def test_only_registered_connections_are_in_connections(self):
+        from explorer.connections import connections
+        from explorer.app_settings import EXPLORER_DEFAULT_CONNECTION
+        from django.db import connections as djcs
+        self.assertTrue(EXPLORER_DEFAULT_CONNECTION in connections)
+        self.assertNotEqual(len(connections), len([c for c in djcs]))
